#!/usr/bin/python
#
# Miscellaneous Tasks (Python Script for GEDitCOM II)

# Load GEDitCOM II Module
from GEDitCOMII import *

################### Subroutines

# Remove RIN tag for all records
# It will remove any number in any location because some software writes
# more than one, even though the extra ones are errors.
# Also merged records might get more than one that need deleting
def RemoveRIN() :
    recs = gdoc.gedcomRecords()
    numRecs = len(recs)
    numDel = 0
    fractionStepSize=nextFraction=0.01
    gdoc.beginUndo()
    for i in range(numRecs) :
        rin = recs[i].findStructuresTag_output_value_("RIN","references",None)
        if len(rin) > 0 :
            numrin = len(rin)
            for j in range(numrin) :
                rin[numrin-1-j].delete()
                numDel += 1
        
        # time for progress
        fractionDone = float(i+1)/float(numRecs)
        if fractionDone > nextFraction:
            ProgressMessage(fractionDone)
            nextFraction += fractionStepSize
    gdoc.endUndoAction_("Delete RIN Tags")
            
    # output summary of the results
    ProgressMessage(1.)
    if numDel==0:
        msg = "No Record Identication Number (RIN) were found in this file."
    else:
        if numDel==1:
            msg = "One Record Identication Number (RIN) tag was deleted."
        else:
            msg = str(numDel)+" Record Identication Number (RIN) tags were deleted."
    Alert("RIN Deletion Done",msg)

# Go through all individuals and sort spouses
def SortSpouses() :
    recs = gdoc.individuals()
    numRecs = len(recs)
    fractionStepSize=nextFraction=0.01
    gdoc.beginUndo()
    for i in range(numRecs) :
        # This code meaans to sort spouses
        recs[i].sortData_(0x736B5350)
        
        # time for progress
        fractionDone = float(i+1)/float(numRecs)
        if fractionDone > nextFraction:
            ProgressMessage(fractionDone)
            nextFraction += fractionStepSize
            
    gdoc.endUndoAction_("Sort Spouses")
            
    # output summary of the results
    ProgressMessage(1.)
    Alert("Sorting of Spouses Done")

################### Main Script

# Preamble
gedit = CheckVersionAndDocument("Miscellaneous Tasks",1.6,2)
if not(gedit) : quit()
gdoc = FrontDocument()

# Pick from currently available editing tasks
choices = ["Delete Record ID Numbers (RIN Tags)","Sort Spouse of All Individuals"]
prompt = "Select the editing task you would like to perform"
otitle = "Miscellaneous Editing Tasks"
option = gdoc.userChoiceListItems_prompt_buttons_multiple_title_(choices,prompt,["OK","Cancel"],False,otitle)
if option[0] == "Cancel":
    quit()

taskID = option[2][0]

# delete RIN
if taskID == 1 :
    RemoveRIN()

elif taskID == 2 :
    SortSpouses()

else :
    Alert("Unknown Task?","The task '"+option[1][0]+"' is not yet supported in this script.")


